@@ -1,17 +1,16 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-r"""Load, analyze, and plot the result of linearizing a Modelica_ model.
+"""Load, analyze, and plot the result of linearizing a Modelica_ model.
 
 This module relies on python-control_, which is included in the distribution.
 
-.. Note::  The following examples are written for Linux.  On Windows\ :sup:`®`,
-   replace the path separators appropriately (change "/" to "\\").
-
 .. _Modelica: http://www.modelica.org/
 .. _python-control: http://sourceforge.net/apps/mediawiki/python-control
 """
 __author__ = "Kevin Davies"
 __email__ = "kdavies4@gmail.com"
+__copyright__ = "Copyright 2012, Georgia Tech Research Corporation"
+__license__ = "BSD-compatible (see LICENSE.txt)"
 
 
 import os
@@ -32,6 +31,80 @@ class LinRes(object):
     those results
     """
 
+    def __init__(self, fname='dslin.mat'):
+        """On initialization, load and preprocess a linearized Modelica_ model
+        (MATLAB\ :sup:`®` format).  The model is in state space:
+
+        .. code-block:: modelica
+
+             der(x) = A*x + B*u;
+                  y = C*x + D*u;
+
+        The linear system is stored as *sys* within this class.  It is an
+        instance of :class:`control.StateSpace`, which emulates the structure
+        of a continuous-time model in MATLAB\ :sup:`®` (e.g., the output of the
+        :meth:`ss` in MATLAB\ :sup:`®`).  It contains:
+
+           - *A*, *B*, *C*, *D*: Matrices of the linear system
+
+           - *stateName*: List of name(s) of the states (x)
+
+           - *inputName*: List of name(s) of the inputs (u)
+
+           - *outputName*: List of name(s) of the outputs (y)
+
+        **Arguments:**
+
+        - *fname*: Name of the file (may include the path)
+
+             The file extension ('.mat') is optional.  The file must contain
+             four matrices:  *Aclass* (specifies the class name, which must be
+             "AlinearSystem"), *nx*, *xuyName*, and *ABCD*.
+
+        **Example:**
+
+           >>> from modelicares import LinRes
+           >>> lin = LinRes('examples/PID')
+        """
+        self._load(fname)
+
+        # Save the base filename and the directory.
+        self.dir, self.fbase = os.path.split(fname)
+        self.dir = os.path.abspath(self.dir)
+        self.fbase = os.path.splitext(self.fbase)[0]
+
+    def __repr__(self):
+        """Return a formal description of the :class:`LinRes` instance.
+
+        **Example:**
+
+        .. code-block:: python
+
+           >>> from modelicares import LinRes
+           >>> lin = LinRes('examples/PID.mat')
+           >>> lin # doctest: +ELLIPSIS
+           LinRes('...PID.mat')
+        """
+        return "%s('%s')" % (self.__class__.__name__,
+                             os.path.join(self.dir, self.fbase + '.mat'))
+        # Note:  The class name is indirectly inquired so that this method will
+        # still be valid if the class is extended.
+
+    def __str__(self):
+        """Return an informal description of the :class:`LinRes` instance.
+
+        **Example:**
+
+        .. code-block:: python
+
+           >>> from modelicares import LinRes
+           >>> lin = LinRes('examples/PID.mat')
+           >>> print(lin) # doctest: +ELLIPSIS
+           Modelica linearization results from "...PID.mat"
+        """
+        return ('Modelica linearization results from "%s"' %
+                os.path.join(self.dir, self.fbase + '.mat'))
+
     def _load(self, fname='dslin.mat'):
         """Load a linearized Modelica_ model from *fname*.
 
@@ -385,80 +458,6 @@ class LinRes(object):
         if ylabel: # Check required for same reason.
             plt.ylabel(ylabel)
 
-    def __repr__(self):
-        """Return a formal description of the :class:`LinRes` instance.
-
-        **Example:**
-
-        .. code-block:: python
-
-           >>> from modelicares import LinRes
-           >>> lin = LinRes('examples/PID.mat')
-           >>> lin # doctest: +ELLIPSIS
-           LinRes('.../examples/PID.mat')
-        """
-        return "%s('%s')" % (self.__class__.__name__,
-                             os.path.join(self.dir, self.fbase + '.mat'))
-        # Note:  The class name is indirectly inquired so that this method will
-        # still be valid if the class is extended.
-
-    def __str__(self):
-        """Return an informal description of the :class:`LinRes` instance.
-
-        **Example:**
-
-        .. code-block:: python
-
-           >>> from modelicares import LinRes
-           >>> lin = LinRes('examples/PID.mat')
-           >>> print lin # doctest: +ELLIPSIS
-           Modelica linearization results from ".../examples/PID.mat"
-        """
-        return ('Modelica linearization results from "%s"' %
-                os.path.join(self.dir, self.fbase + '.mat'))
-
-    def __init__(self, fname='dslin.mat'):
-        """On initialization, load and preprocess a linearized Modelica_ model
-        (MATLAB\ :sup:`®` format).  The model is in state space:
-
-        .. code-block:: modelica
-
-             der(x) = A*x + B*u;
-                  y = C*x + D*u;
-
-        The linear system is stored as *sys* within this class.  It is an
-        instance of :class:`control.StateSpace`, which emulates the structure
-        of a continuous-time model in MATLAB\ :sup:`®` (e.g., the output of the
-        :meth:`ss` in MATLAB\ :sup:`®`).  It contains:
-
-           - *A*, *B*, *C*, *D*: Matrices of the linear system
-
-           - *stateName*: List of name(s) of the states (x)
-
-           - *inputName*: List of name(s) of the inputs (u)
-
-           - *outputName*: List of name(s) of the outputs (y)
-
-        **Arguments:**
-
-        - *fname*: Name of the file (may include the path)
-
-             The file extension ('.mat') is optional.  The file must contain
-             four matrices:  *Aclass* (specifies the class name, which must be
-             "AlinearSystem"), *nx*, *xuyName*, and *ABCD*.
-
-        **Example:**
-
-           >>> from modelicares import LinRes
-           >>> lin = LinRes('examples/PID')
-        """
-        self._load(fname)
-
-        # Save the base filename and the directory.
-        self.dir, self.fbase = os.path.split(fname)
-        self.dir = os.path.abspath(self.dir)
-        self.fbase = os.path.splitext(self.fbase)[0]
-
 
 if __name__ == '__main__':
     """Test the contents of this file."""
