@@ -1,15 +1,15 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-r"""Load, analyze, and plot results from Modelica_ simulations.
-
-.. Note::  The following examples are written for Linux.  On Windows\ :sup:`®`,
-   replace the path separators appropriately (change "/" to "\\").
+"""Load, analyze, and plot results from Modelica_ simulations.
 
 .. _Modelica: http://www.modelica.org/
 """
 __author__ = "Kevin Davies"
-__credits__ = ["Kevin Bandy", "Joerg Raedler"]
 __email__ = "kdavies4@gmail.com"
+__credits__ = ["Kevin Bandy", "Joerg Raedler"]
+__copyright__ = "Copyright 2012, Georgia Tech Research Corporation"
+__license__ = "BSD-compatible (see LICENSE.txt)"
+
 
 #TODO:
 #  1. Add support to convert units from the data space to the axis space
@@ -79,7 +79,30 @@ class SimRes(object):
     those results
     """
 
-    # TODO: Remove the "_" prefix once this is fixed, tested, and ready.
+    def __init__(self, fname='dsres.mat'):
+        """On initialization, load Modelica_ simulation results from a
+        MATLAB\ :sup:`®` file in Dymola\ :sup:`®` format.
+
+        **Arguments:**
+
+        - *fname*: Name of the file (may include the path)
+
+             The file extension ('.mat') is optional.
+
+        **Example:**
+
+           >>> from modelicares import SimRes
+           >>> sim = SimRes('examples/ChuaCircuit')
+        """
+        self._load(fname)
+
+        # Save the base filename and the directory.
+        self.dir, self.fbase = os.path.split(fname)
+        self.dir = os.path.abspath(self.dir)
+        self.fbase = os.path.splitext(self.fbase)[0]
+
+    # TODO: Remove the "_" prefix and NotImpletedError once this is fixed and
+    # tested.
     def _bar(self, names, times=[0], width=0.6, n_rows=1,
              title=None, subtitles=[], label="bar",
              xlabel=None, xticklabels=None, ylabel=None,
@@ -157,7 +180,7 @@ class SimRes(object):
 
         1. List of the axes within the figure
         """
-        raise NotImplementedError, "Needs work"
+        raise NotImplementedError
 
         # Indices for the bars (1, 2, ...)
         ind = np.arange(len(names)) + 1
@@ -1238,7 +1261,7 @@ class SimRes(object):
            >>> from modelicares import SimRes
            >>> sim = SimRes('examples/ChuaCircuit.mat')
            >>> sim # doctest: +ELLIPSIS
-           SimRes('.../examples/ChuaCircuit.mat')
+           SimRes('...ChuaCircuit.mat')
         """
         return "%s('%s')" % (self.__class__.__name__,
                              os.path.join(self.dir, self.fbase + '.mat'))
@@ -1252,34 +1275,12 @@ class SimRes(object):
 
            >>> from modelicares import SimRes
            >>> sim = SimRes('examples/ChuaCircuit.mat')
-           >>> print sim # doctest: +ELLIPSIS
-           Modelica simulation results from ".../examples/ChuaCircuit.mat"
+           >>> print(sim) # doctest: +ELLIPSIS
+           Modelica simulation results from "...ChuaCircuit.mat"
         """
         return ('Modelica simulation results from "%s"' %
                 os.path.join(self.dir, self.fbase + '.mat'))
 
-    def __init__(self, fname='dsres.mat'):
-        """On initialization, load Modelica_ simulation results from a
-        MATLAB\ :sup:`®` file in Dymola\ :sup:`®` format.
-
-        **Arguments:**
-
-        - *fname*: Name of the file (may include the path)
-
-             The file extension ('.mat') is optional.
-
-        **Example:**
-
-           >>> from modelicares import SimRes
-           >>> sim = SimRes('examples/ChuaCircuit')
-        """
-        self._load(fname)
-
-        # Save the base filename and the directory.
-        self.dir, self.fbase = os.path.split(fname)
-        self.dir = os.path.abspath(self.dir)
-        self.fbase = os.path.splitext(self.fbase)[0]
-
 
 class Info:
     """Shortcuts to the "get" methods in :class:`SimRes`
